@@ -92,8 +92,9 @@ const Application = new Lang.Class({
           { name: 'edit-connection',
             activate: Lang.bind(this, this._onEditConnection),
             parameter_type: GLib.VariantType.new('o') },
-          { name: 'preferences',
-            activate: Lang.bind(this, this._onShowPreferences) },
+          { name: 'help',
+            activate: Lang.bind(this, this._onShowHelp),
+            accels: ['F1'] },
           { name: 'about',
             activate: Lang.bind(this, this._onShowAbout) },
           { name: 'quit',
@@ -191,6 +192,10 @@ const Application = new Lang.Class({
             if (!success)
                 return;
 
+            // When launching Polari via a URL, there is a potential race
+            // condition between networksManager and AccountsManager here. If
+            // AccountsManager finishes first, networksManager's list of
+            // servers would be empty and hence no matches would be found.
             let matchedId = this._networksManager.findByServer(server);
             let matches = Object.keys(map).filter(function(a) {
                 return GLib.ascii_strcasecmp(map[a].server, server) == 0 ||
@@ -349,9 +354,7 @@ const Application = new Lang.Class({
 
     _updateAccountServer: function(account, server, callback) {
         let sv = { server: GLib.Variant.new('s', server.address),
-                   port: GLib.Variant.new('u', server.port),
-                   'use-ssl': GLib.Variant.new('b', server.ssl)
-                    };
+                   port: GLib.Variant.new('u', server.port) };
         let asv = GLib.Variant.new('a{sv}', sv);
         account.update_parameters_vardict_async(asv, [], callback);
     },
@@ -393,7 +396,7 @@ const Application = new Lang.Class({
           retry: 0,
           originalNick: account.nickname,
           callback: callback,
-          alternateServers: accountServers.filter(s => s.address != server)
+          alternateServers: accountServers.filter(s => s != server)
         };
 
         this._pendingRequests[roomId] = requestData;
@@ -592,7 +595,8 @@ const Application = new Lang.Class({
         dialog.show();
     },
 
-    _onShowPreferences: function() {
+    _onShowHelp: function() {
+        Utils.openURL('help:org.gnome.Polari', Gtk.get_current_event_time());
     },
 
     _onShowAbout: function() {
