@@ -303,7 +303,7 @@ const EntryArea = new Lang.Class({
     },
 
     pasteFile: function(file) {
-        file.query_info_async(Gio.FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+        file.query_info_async(Gio.FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
                               Gio.FileQueryInfoFlags.NONE,
                               GLib.PRIORITY_DEFAULT, null,
                               Lang.bind(this, this._onFileInfoReady));
@@ -317,25 +317,12 @@ const EntryArea = new Lang.Class({
             return;
         }
 
-        let contentType = fileInfo.get_content_type();
-
-        if (Gio.content_type_is_a(contentType, 'text/plain'))
-            file.load_contents_async(null, Lang.bind(this,
-                function(f, res) {
-                    let [, contents, ,] = f.load_contents_finish(res);
-                    let text = contents.toString();
-                    this.pasteText(text, text.length);
-                }));
-        else if (Gio.content_type_is_a(contentType, 'image/*'))
-            file.read_async(GLib.PRIORITY_DEFAULT, null, Lang.bind(this,
-                function(f, res) {
-                    let stream = f.read_finish(res);
-                    GdkPixbuf.Pixbuf.new_from_stream_async(stream, null,
-                        Lang.bind(this, function(stream, res) {
-                            let pixbuf = GdkPixbuf.Pixbuf.new_from_stream_finish(res);
-                            this.pasteImage(pixbuf);
-                        }));
-                }));
+        let name = fileInfo.get_display_name();
+        /* Translators: %s is a filename */
+        this._confirmLabel.label = _("Upload “%s” to public paste service?").format(name);
+        /* Translators: %s is a filename */
+        this._uploadLabel.label = _("Uploading “%s” to public paste service …").format(name);
+        this._setPasteContent(file);
     },
 
     _onPasteClicked: function() {
