@@ -38,13 +38,19 @@ const RoomRow = new Lang.Class({
         this.connect('key-press-event',
                      Lang.bind(this, this._onKeyPress));
 
-        room.connect('notify::channel',
-                     Lang.bind(this, this._onChannelChanged));
+        room.connect('notify::channel', Lang.bind(this,
+            function() {
+                if (!room.channel)
+                    return;
+                room.channel.connect('message-received',
+                                     Lang.bind(this, this._updatePending));
+                room.channel.connect('pending-message-removed',
+                                     Lang.bind(this, this._updatePending));
+            }));
         room.bind_property('display-name', this._roomLabel, 'label',
                            GObject.BindingFlags.SYNC_CREATE);
 
         this._updatePending();
-        this._onChannelChanged();
     },
 
     get room() {
@@ -64,44 +70,35 @@ const RoomRow = new Lang.Class({
             this._updatePending();
     },
 
-    _getNumPending: function() {
-        if (!this._room.channel)
-            return [0, 0];
-
-        let pending = this._room.channel.dup_pending_messages();
-        let nPending = pending.length;
-        if (!this._room.channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP))
-            return [nPending, nPending];
-
-        let highlights = pending.filter(m => {
-            return this._room.should_highlight_message(m);
-        });
-        return [nPending, highlights.length];
-    },
-
     _updatePending: function() {
-        let [nPending, nHighlights] = this._getNumPending();
+        let room = this._room;
 
-        this._counter.label = nHighlights.toString();
-        this._counter.opacity = nHighlights > 0 ? 1. : 0.;
+        let pending;
+        let numPendingHighlights;
+
+        if (room.channel) {
+            pending = room.channel.dup_pending_messages();
+            if (room.channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP))
+                numPendingHighlights = pending.filter(function(m) {
+                    return room.should_highlight_message(m);
+                }).length;
+            else
+                numPendingHighlights = pending.length;
+        } else {
+            pending = [];
+            numPendingHighlights = 0;
+        }
+
+        this._counter.label = numPendingHighlights.toString();
+        this._counter.opacity = numPendingHighlights > 0 ? 1. : 0.;
 
         let context = this.get_style_context();
-        if (nPending == 0)
+        if (pending.length == 0)
             context.add_class('inactive');
         else
             context.remove_class('inactive');
     },
 
-    _onChannelChanged: function() {
-        if (!this._room.channel)
-            return;
-        this._room.channel.connect('message-received',
-                                   Lang.bind(this, this._updatePending));
-        this._room.channel.connect('pending-message-removed',
-                                   Lang.bind(this, this._updatePending));
-        this._updatePending();
-    },
-
     _onButtonRelease: function(w, event) {
         let [, button] = event.get_button();
         if (button != Gdk.BUTTON_SECONDARY)
